@@ -7,7 +7,6 @@ from django.urls import reverse
 from esi.models import Token
 
 from allianceauth.authentication.models import CharacterOwnership
-from allianceauth.eveonline.models import EveCharacter
 from app_utils.testing import NoSocketsTestCase, create_user_from_evecharacter
 
 from .. import views
@@ -63,15 +62,15 @@ class TestMainScreen(LoadTestDataMixin, TestCase):
         response = views.index(request)
         self.assertEqual(response.status_code, 302)
 
-    @patch(MODULE_PATH + ".messages_plus")
-    def test_user_can_remove_sync_char(self, mock_messages_plus):
+    @patch(MODULE_PATH + ".messages")
+    def test_user_can_remove_sync_char(self, mock_messages):
         request = self.factory.get(
             reverse("standingssync:remove_character", args=(self.sync_char.pk,))
         )
         request.user = self.user_2
         response = views.remove_character(request, self.sync_char.pk)
         self.assertEqual(response.status_code, 302)
-        self.assertTrue(mock_messages_plus.success.called)
+        self.assertTrue(mock_messages.success.called)
         self.assertFalse(SyncedCharacter.objects.filter(pk=self.sync_char.pk).exists())
 
     def test_user_with_permission_can_set_alliance_char(self):
@@ -82,7 +81,7 @@ class TestMainScreen(LoadTestDataMixin, TestCase):
 
 
 @patch(MODULE_PATH + ".tasks.run_character_sync")
-@patch(MODULE_PATH + ".messages_plus")
+@patch(MODULE_PATH + ".messages")
 class TestAddSyncChar(LoadTestDataMixin, NoSocketsTestCase):
     @classmethod
     def setUpClass(cls):
@@ -129,19 +128,19 @@ class TestAddSyncChar(LoadTestDataMixin, NoSocketsTestCase):
         return orig_view(request, token)
 
     def test_users_can_not_add_alliance_members(
-        self, mock_messages_plus, mock_run_character_sync
+        self, mock_messages, mock_run_character_sync
     ):
         response = self.make_request(self.user_2, self.character_2)
         self.assertEqual(response.status_code, 302)
         self.assertEqual(response.url, reverse("standingssync:index"))
-        self.assertTrue(mock_messages_plus.warning.called)
+        self.assertTrue(mock_messages.warning.called)
         self.assertFalse(mock_run_character_sync.delay.called)
 
-    def test_user_can_add_blue_alt(self, mock_messages_plus, mock_run_character_sync):
+    def test_user_can_add_blue_alt(self, mock_messages, mock_run_character_sync):
         response = self.make_request(self.user_2, self.character_4)
         self.assertEqual(response.status_code, 302)
         self.assertEqual(response.url, reverse("standingssync:index"))
-        self.assertTrue(mock_messages_plus.success.called)
+        self.assertTrue(mock_messages.success.called)
         self.assertTrue(mock_run_character_sync.delay.called)
         self.assertTrue(
             SyncedCharacter.objects.filter(manager=self.sync_manager)
@@ -150,13 +149,11 @@ class TestAddSyncChar(LoadTestDataMixin, NoSocketsTestCase):
         )
 
     @patch(MODULE_PATH + ".STANDINGSSYNC_CHAR_MIN_STANDING", 0)
-    def test_user_can_add_neutral_alt(
-        self, mock_messages_plus, mock_run_character_sync
-    ):
+    def test_user_can_add_neutral_alt(self, mock_messages, mock_run_character_sync):
         response = self.make_request(self.user_2, self.character_6)
         self.assertEqual(response.status_code, 302)
         self.assertEqual(response.url, reverse("standingssync:index"))
-        self.assertTrue(mock_messages_plus.success.called)
+        self.assertTrue(mock_messages.success.called)
         self.assertTrue(mock_run_character_sync.delay.called)
         self.assertTrue(
             SyncedCharacter.objects.filter(manager=self.sync_manager)
@@ -165,12 +162,12 @@ class TestAddSyncChar(LoadTestDataMixin, NoSocketsTestCase):
         )
 
     def test_user_can_not_add_non_blue_alt(
-        self, mock_messages_plus, mock_run_character_sync
+        self, mock_messages, mock_run_character_sync
     ):
         response = self.make_request(self.user_2, self.character_5)
         self.assertEqual(response.status_code, 302)
         self.assertEqual(response.url, reverse("standingssync:index"))
-        self.assertTrue(mock_messages_plus.warning.called)
+        self.assertTrue(mock_messages.warning.called)
         self.assertFalse(mock_run_character_sync.delay.called)
         self.assertFalse(
             SyncedCharacter.objects.filter(manager=self.sync_manager)
@@ -178,45 +175,9 @@ class TestAddSyncChar(LoadTestDataMixin, NoSocketsTestCase):
             .exists()
         )
 
-    def test_user_can_not_add_char_users_down_not_own(
-        self, mock_messages_plus, mock_run_character_sync
-    ):
-        response = self.make_request(self.user_2, self.character_3)
-        self.assertEqual(response.status_code, 302)
-        self.assertEqual(response.url, reverse("standingssync:index"))
-        self.assertTrue(mock_messages_plus.warning.called)
-        self.assertFalse(mock_run_character_sync.delay.called)
-        self.assertFalse(
-            SyncedCharacter.objects.filter(manager=self.sync_manager)
-            .filter(character_ownership__character=self.character_3)
-            .exists()
-        )
 
-    def test_raises_exception_if_alliance_not_found(
-        self, mock_messages_plus, mock_run_character_sync
-    ):
-        my_char = EveCharacter.objects.create(
-            character_id=1098,
-            character_name="Joker",
-            corporation_id=2098,
-            corporation_name="Joker Corp",
-            alliance_id=3098,
-            alliance_name="Joker Alliance",
-        )
-        my_user, _ = create_user_from_evecharacter(my_char.character_id)
-        with self.assertRaises(RuntimeError):
-            self.make_request(my_user, self.character_4)
-
-    def test_raises_exception_if_no_sync_manager_for_alliance(
-        self, mock_messages_plus, mock_run_character_sync
-    ):
-        my_user, _ = create_user_from_evecharacter(self.character_3.character_id)
-        with self.assertRaises(RuntimeError):
-            self.make_request(my_user, self.character_4)
-
-
-@patch(MODULE_PATH + ".tasks.run_manager_sync")
-@patch(MODULE_PATH + ".messages_plus")
+@patch(MODULE_PATH + ".tasks")
+@patch(MODULE_PATH + ".messages")
 class TestAddAllianceManager(LoadTestDataMixin, NoSocketsTestCase):
     @classmethod
     def setUpClass(cls):
@@ -264,27 +225,41 @@ class TestAddAllianceManager(LoadTestDataMixin, NoSocketsTestCase):
         return orig_view(request, token)
 
     def test_user_with_permission_can_add_alliance_manager(
-        self, mock_messages_plus, mock_run_manager_sync
+        self, mock_messages, mock_tasks
     ):
         response = self.make_request(self.user_1, self.character_1)
         self.assertEqual(response.status_code, 302)
         self.assertEqual(response.url, reverse("standingssync:index"))
-        self.assertTrue(mock_messages_plus.success.called)
-        self.assertTrue(mock_run_manager_sync.delay.called)
+        self.assertTrue(mock_messages.success.called)
+        self.assertTrue(mock_tasks.run_manager_sync.delay.called)
         self.assertTrue(
             SyncManager.objects.filter(alliance=self.alliance_1)
             .filter(character_ownership__character=self.character_1)
             .exists()
         )
 
+    def test_should_sync_wars_when_adding_alliance_char_and_feature_enabled(
+        self, mock_messages, mock_tasks
+    ):
+        with patch(MODULE_PATH + ".STANDINGSSYNC_ADD_WAR_TARGETS", True):
+            self.make_request(self.user_1, self.character_1)
+        self.assertTrue(mock_tasks.sync_all_wars.delay.called)
+
+    def test_should_not_sync_wars_when_adding_alliance_char_and_feature_disabled(
+        self, mock_messages, mock_tasks
+    ):
+        with patch(MODULE_PATH + ".STANDINGSSYNC_ADD_WAR_TARGETS", False):
+            self.make_request(self.user_1, self.character_1)
+        self.assertFalse(mock_tasks.sync_all_wars.delay.called)
+
     """
     def test_user_wo_permission_can_not_add_alliance_manager(
-        self, mock_messages_plus, mock_run_manager_sync
+        self, mock_messages, mock_tasks
     ):
         response = self.make_request(self.user_2, self.character_2)
         self.assertEqual(response.status_code, 302)
         self.assertEqual(response.url, reverse('standingssync:index'))
-        self.assertFalse(mock_run_manager_sync.delay.called)
+        self.assertFalse(mock_tasks.delay.called)
         self.assertFalse(
             SyncManager.objects
             .filter(alliance=self.alliance_1)
@@ -294,29 +269,15 @@ class TestAddAllianceManager(LoadTestDataMixin, NoSocketsTestCase):
     """
 
     def test_character_for_manager_must_be_alliance_member(
-        self, mock_messages_plus, mock_run_manager_sync
+        self, mock_messages, mock_tasks
     ):
         response = self.make_request(self.user_1, self.character_5)
         self.assertEqual(response.status_code, 302)
         self.assertEqual(response.url, reverse("standingssync:index"))
-        self.assertTrue(mock_messages_plus.warning.called)
-        self.assertFalse(mock_run_manager_sync.delay.called)
+        self.assertTrue(mock_messages.warning.called)
+        self.assertFalse(mock_tasks.run_manager_sync.delay.called)
         self.assertFalse(
             SyncManager.objects.filter(alliance=self.alliance_1)
             .filter(character_ownership__character=self.character_5)
             .exists()
         )
-
-    def test_character_for_manager_must_be_owned_by_user(
-        self, mock_messages_plus, mock_run_manager_sync
-    ):
-        response = self.make_request(self.user_1, self.character_3)
-        self.assertEqual(response.status_code, 302)
-        self.assertEqual(response.url, reverse("standingssync:index"))
-        self.assertTrue(mock_messages_plus.warning.called)
-        self.assertFalse(mock_run_manager_sync.delay.called)
-        self.assertFalse(
-            SyncManager.objects.filter(alliance=self.alliance_1)
-            .filter(character_ownership__character=self.character_3)
-            .exists()
-        )
